
## Summary
Replace pronouns with the nouns they represent.

## Installing
`pip install depronounize`

## Usage
```
from depronounize.depronounize import replace_pronouns

print(replace_pronouns("I went to buy jam, but they were out of it."))
```

## Uploading to PyPi
0. `cd <top-level-working-dir>
1. `python setup.py sdist`
2. `twine upload dist/*`

